==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-incident-mgmt-itil/dictionaries/nl.dict.itop-incident-mgmt-itil.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author Thomas Casteleyn <info@super-visions.com>
 * @author Jeffrey Bostoen <info@jeffreybostoen.be> (2018 - 2022)
 *
 */
Dict::Add('NL NL', 'Dutch', 'Nederlands', [
	'Class:Incident' => 'Incident',
	'Class:Incident+' => '',
	'Class:Incident/Attribute:assignment_date' => 'Toegewezen sinds',
	'Class:Incident/Attribute:assignment_date+' => '',
	'Class:Incident/Attribute:child_incidents_list' => 'Subincidenten',
	'Class:Incident/Attribute:child_incidents_list+' => 'Alle subincidenten gerelateerd aan dit incident',
	'Class:Incident/Attribute:cumulatedpending' => 'Totaal in afwachting',
	'Class:Incident/Attribute:cumulatedpending+' => '',
	'Class:Incident/Attribute:escalation_flag' => 'Geëscaleerd',
	'Class:Incident/Attribute:escalation_flag+' => '',
	'Class:Incident/Attribute:escalation_flag/Value:no' => 'Nee',
	'Class:Incident/Attribute:escalation_flag/Value:no+' => 'Nee',
	'Class:Incident/Attribute:escalation_flag/Value:yes' => 'Ja',
	'Class:Incident/Attribute:escalation_flag/Value:yes+' => 'Ja',
	'Class:Incident/Attribute:escalation_reason' => 'Reden voor escalatie',
	'Class:Incident/Attribute:escalation_reason+' => '',
	'Class:Incident/Attribute:impact' => 'Impact',
	'Class:Incident/Attribute:impact+' => '',
	'Class:Incident/Attribute:impact/Value:1' => 'Afdeling',
	'Class:Incident/Attribute:impact/Value:1+' => '',
	'Class:Incident/Attribute:impact/Value:2' => 'Dienst',
	'Class:Incident/Attribute:impact/Value:2+' => '',
	'Class:Incident/Attribute:impact/Value:3' => 'Persoon',
	'Class:Incident/Attribute:impact/Value:3+' => '',
	'Class:Incident/Attribute:last_pending_date' => 'Laatst in afwachting sinds',
	'Class:Incident/Attribute:last_pending_date+' => 'Laatste datum waarop het incident de status in afwachting had',
	'Class:Incident/Attribute:origin' => 'Oorsprong',
	'Class:Incident/Attribute:origin+' => '',
	'Class:Incident/Attribute:origin/Value:chat' => 'Chat',
	'Class:Incident/Attribute:origin/Value:chat+' => 'Chat',
	'Class:Incident/Attribute:origin/Value:in_person' => 'Persoonlijk',
	'Class:Incident/Attribute:origin/Value:in_person+' => 'Mondeling, in persoon',
	'Class:Incident/Attribute:origin/Value:mail' => 'E-mail',
	'Class:Incident/Attribute:origin/Value:mail+' => 'E-mail',
	'Class:Incident/Attribute:origin/Value:monitoring' => 'Monitoring',
	'Class:Incident/Attribute:origin/Value:monitoring+' => 'Monitoring',
	'Class:Incident/Attribute:origin/Value:phone' => 'Telefoon',
	'Class:Incident/Attribute:origin/Value:phone+' => 'Telefoon',
	'Class:Incident/Attribute:origin/Value:portal' => 'Portaal',
	'Class:Incident/Attribute:origin/Value:portal+' => 'Portaal',
	'Class:Incident/Attribute:parent_change_id' => 'Hoofdchange',
	'Class:Incident/Attribute:parent_change_id+' => '',
	'Class:Incident/Attribute:parent_change_ref' => 'Ref. hoofdchange',
	'Class:Incident/Attribute:parent_change_ref+' => '',
	'Class:Incident/Attribute:parent_incident_id' => 'Hoofdincident',
	'Class:Incident/Attribute:parent_incident_id+' => '',
	'Class:Incident/Attribute:parent_incident_id_friendlyname' => 'Ref. hoofdincident',
	'Class:Incident/Attribute:parent_incident_id_friendlyname+' => '',
	'Class:Incident/Attribute:parent_incident_ref' => 'Ref. hoofdincident',
	'Class:Incident/Attribute:parent_incident_ref+' => '',
	'Class:Incident/Attribute:parent_problem_id' => 'Hoofdprobleem',
	'Class:Incident/Attribute:parent_problem_id+' => '',
	'Class:Incident/Attribute:parent_problem_ref' => 'Ref. hoofdprobleem',
	'Class:Incident/Attribute:parent_problem_ref+' => '',
	'Class:Incident/Attribute:pending_reason' => 'Reden in afwachting',
	'Class:Incident/Attribute:pending_reason+' => 'Reden waarvoor het in afwachting staat',
	'Class:Incident/Attribute:priority' => 'Prioriteit',
	'Class:Incident/Attribute:priority+' => '',
	'Class:Incident/Attribute:priority/Value:1' => 'Kritisch',
	'Class:Incident/Attribute:priority/Value:1+' => 'Kritisch',
	'Class:Incident/Attribute:priority/Value:2' => 'Hoog',
	'Class:Incident/Attribute:priority/Value:2+' => 'Hoog',
	'Class:Incident/Attribute:priority/Value:3' => 'Normaal',
	'Class:Incident/Attribute:priority/Value:3+' => 'Normaal',
	'Class:Incident/Attribute:priority/Value:4' => 'Laag',
	'Class:Incident/Attribute:priority/Value:4+' => 'Laag',
	'Class:Incident/Attribute:public_log' => 'Publieke log',
	'Class:Incident/Attribute:public_log+' => '',
	'Class:Incident/Attribute:related_request_list' => 'Subverzoeken',
	'Class:Incident/Attribute:related_request_list+' => '',
	'Class:Incident/Attribute:resolution_code' => 'Code oplossing',
	'Class:Incident/Attribute:resolution_code+' => '',
	'Class:Incident/Attribute:resolution_code/Value:assistance' => 'Assistentie',
	'Class:Incident/Attribute:resolution_code/Value:assistance+' => 'Assistentie',
	'Class:Incident/Attribute:resolution_code/Value:bug fixed' => 'Bug opgelost',
	'Class:Incident/Attribute:resolution_code/Value:bug fixed+' => 'Bug opgelost',
	'Class:Incident/Attribute:resolution_code/Value:hardware repair' => 'Hardware gerepareerd',
	'Class:Incident/Attribute:resolution_code/Value:hardware repair+' => 'Hardware gerepareerd',
	'Class:Incident/Attribute:resolution_code/Value:other' => 'Anders',
	'Class:Incident/Attribute:resolution_code/Value:other+' => 'Anders',
	'Class:Incident/Attribute:resolution_code/Value:software patch' => 'Softwarepatch',
	'Class:Incident/Attribute:resolution_code/Value:software patch+' => 'Softwarepatch',
	'Class:Incident/Attribute:resolution_code/Value:system update' => 'Systeemupdate',
	'Class:Incident/Attribute:resolution_code/Value:system update+' => 'Systeemupdate',
	'Class:Incident/Attribute:resolution_code/Value:training' => 'Training',
	'Class:Incident/Attribute:resolution_code/Value:training+' => 'Training',
	'Class:Incident/Attribute:resolution_date' => 'Opgelost sinds',
	'Class:Incident/Attribute:resolution_date+' => '',
	'Class:Incident/Attribute:service_id' => 'Service',
	'Class:Incident/Attribute:service_id+' => '',
	'Class:Incident/Attribute:service_name' => 'Naam service',
	'Class:Incident/Attribute:service_name+' => '',
	'Class:Incident/Attribute:servicesubcategory_id' => 'Subcategorie service',
	'Class:Incident/Attribute:servicesubcategory_id+' => '',
	'Class:Incident/Attribute:servicesubcategory_name' => 'Naam subcategorie service',
	'Class:Incident/Attribute:servicesubcategory_name+' => '',
	'Class:Incident/Attribute:sla_tto_over' => 'SLA TTO overschreden',
	'Class:Incident/Attribute:sla_tto_over+' => '',
	'Class:Incident/Attribute:sla_tto_passed' => 'SLA TTO gepasseerd',
	'Class:Incident/Attribute:sla_tto_passed+' => '',
	'Class:Incident/Attribute:sla_ttr_over' => 'SLA TTR overschreden',
	'Class:Incident/Attribute:sla_ttr_over+' => '',
	'Class:Incident/Attribute:sla_ttr_passed' => 'SLA TTR gepasseerd',
	'Class:Incident/Attribute:sla_ttr_passed+' => '',
	'Class:Incident/Attribute:solution' => 'Oplossing',
	'Class:Incident/Attribute:solution+' => 'Oplossing',
	'Class:Incident/Attribute:status' => 'Status',
	'Class:Incident/Attribute:status+' => '',
	'Class:Incident/Attribute:status/Value:assigned' => 'Toegewezen',
	'Class:Incident/Attribute:status/Value:assigned+' => '',
	'Class:Incident/Attribute:status/Value:closed' => 'Gesloten',
	'Class:Incident/Attribute:status/Value:closed+' => '',
	'Class:Incident/Attribute:status/Value:escalated_tto' => 'Geëscaleerde TTO',
	'Class:Incident/Attribute:status/Value:escalated_tto+' => '',
	'Class:Incident/Attribute:status/Value:escalated_ttr' => 'Geëscaleerde TTR',
	'Class:Incident/Attribute:status/Value:escalated_ttr+' => '',
	'Class:Incident/Attribute:status/Value:new' => 'Nieuw',
	'Class:Incident/Attribute:status/Value:new+' => '',
	'Class:Incident/Attribute:status/Value:pending' => 'In afwachting',
	'Class:Incident/Attribute:status/Value:pending+' => '',
	'Class:Incident/Attribute:status/Value:resolved' => 'Opgelost',
	'Class:Incident/Attribute:status/Value:resolved+' => '',
	'Class:Incident/Attribute:status/Value:waiting_for_approval' => 'Wachten op goedkeuring',
	'Class:Incident/Attribute:status/Value:waiting_for_approval+' => '',
	'Class:Incident/Attribute:time_spent' => 'Gespendeerde tijd',
	'Class:Incident/Attribute:time_spent+' => '',
	'Class:Incident/Attribute:tto' => 'TTO',
	'Class:Incident/Attribute:tto+' => '',
	'Class:Incident/Attribute:tto_escalation_deadline' => 'Deadline TTO',
	'Class:Incident/Attribute:tto_escalation_deadline+' => '',
	'Class:Incident/Attribute:ttr' => 'TTR',
	'Class:Incident/Attribute:ttr+' => '',
	'Class:Incident/Attribute:ttr_escalation_deadline' => 'Deadline TTR',
	'Class:Incident/Attribute:ttr_escalation_deadline+' => '',
	'Class:Incident/Attribute:urgency' => 'Urgentie',
	'Class:Incident/Attribute:urgency+' => '',
	'Class:Incident/Attribute:urgency/Value:1' => 'Kritisch',
	'Class:Incident/Attribute:urgency/Value:1+' => 'Kritisch',
	'Class:Incident/Attribute:urgency/Value:2' => 'Hoog',
	'Class:Incident/Attribute:urgency/Value:2+' => 'Hoog',
	'Class:Incident/Attribute:urgency/Value:3' => 'Normaal',
	'Class:Incident/Attribute:urgency/Value:3+' => 'Normaal',
	'Class:Incident/Attribute:urgency/Value:4' => 'Laag',
	'Class:Incident/Attribute:urgency/Value:4+' => 'Laag',
	'Class:Incident/Attribute:user_comment' => 'Reactie gebruiker',
	'Class:Incident/Attribute:user_comment+' => '',
	'Class:Incident/Attribute:user_satisfaction' => 'Klanttevredenheid',
	'Class:Incident/Attribute:user_satisfaction+' => '',
	'Class:Incident/Attribute:user_satisfaction/Value:1' => 'Erg tevreden',
	'Class:Incident/Attribute:user_satisfaction/Value:1+' => 'Erg tevreden',
	'Class:Incident/Attribute:user_satisfaction/Value:2' => 'Tevreden',
	'Class:Incident/Attribute:user_satisfaction/Value:2+' => 'Tevreden',
	'Class:Incident/Attribute:user_satisfaction/Value:3' => 'Ontevreden',
	'Class:Incident/Attribute:user_satisfaction/Value:3+' => 'Ontevreden',
	'Class:Incident/Attribute:user_satisfaction/Value:4' => 'Erg ontevreden',
	'Class:Incident/Attribute:user_satisfaction/Value:4+' => 'Erg ontevreden',
	'Class:Incident/Error:CannotAssignParentIncidentIdToSelf' => 'Kan het incident niet aan zichzelf toewijzen als hoofdincident',
	'Class:Incident/Method:ResolveChildTickets' => 'ResolveChildTickets',
	'Class:Incident/Method:ResolveChildTickets+' => 'Pas de oplossing ook toe op subverzoeken (ev_autoresolve) en neem deze kenmerken over: service, team, agent, oplossing',
	'Class:Incident/Stimulus:ev_assign' => 'Wijs toe',
	'Class:Incident/Stimulus:ev_assign+' => '',
	'Class:Incident/Stimulus:ev_autoclose' => 'Sluit automatisch',
	'Class:Incident/Stimulus:ev_autoclose+' => '',
	'Class:Incident/Stimulus:ev_autoresolve' => 'Los automatisch op',
	'Class:Incident/Stimulus:ev_autoresolve+' => '',
	'Class:Incident/Stimulus:ev_close' => 'Sluit dit incident',
	'Class:Incident/Stimulus:ev_close+' => '',
	'Class:Incident/Stimulus:ev_pending' => 'In afwachting',
	'Class:Incident/Stimulus:ev_pending+' => '',
	'Class:Incident/Stimulus:ev_reassign' => 'Wijs opnieuw toe',
	'Class:Incident/Stimulus:ev_reassign+' => '',
	'Class:Incident/Stimulus:ev_reopen' => 'Heropen',
	'Class:Incident/Stimulus:ev_reopen+' => '',
	'Class:Incident/Stimulus:ev_resolve' => 'Los op',
	'Class:Incident/Stimulus:ev_resolve+' => '',
	'Class:Incident/Stimulus:ev_timeout' => 'Time-out',
	'Class:Incident/Stimulus:ev_timeout+' => '',
	'Menu:Incident:EscalatedIncidents' => 'Geëscaleerde incidenten',
	'Menu:Incident:EscalatedIncidents+' => 'Geëscaleerde incidenten',
	'Menu:Incident:MyIncidents' => 'Incidenten toegewezen aan mij',
	'Menu:Incident:MyIncidents+' => 'Incidenten toegewezen aan mij (als Agent)',
	'Menu:Incident:OpenIncidents' => 'Alle open incidenten',
	'Menu:Incident:OpenIncidents+' => 'Alle open incidenten',
	'Menu:Incident:Overview' => 'Overzicht',
	'Menu:Incident:Overview+' => 'Overzicht',
	'Menu:Incident:Shortcuts' => 'Snelkoppelingen',
	'Menu:Incident:Shortcuts+' => '',
	'Menu:IncidentManagement' => 'Incident Management',
	'Menu:IncidentManagement+' => 'Incident Management',
	'Menu:NewIncident' => 'Nieuw incident',
	'Menu:NewIncident+' => 'Maak een nieuw incident aan',
	'Menu:SearchIncidents' => 'Zoek naar incidenten',
	'Menu:SearchIncidents+' => 'Zoek naar incidenten',
	'Tickets:Related:OpenIncidents' => 'Open incidenten',
	'UI-IncidentManagementOverview-IncidentByPriority-last-14-days' => 'Incidenten van de afgelopen 14 dagen (per prioriteit)',
	'UI-IncidentManagementOverview-Last-14-days' => 'Incidenten van de afgelopen 14 dagen (per dag)',
	'UI-IncidentManagementOverview-OpenIncidentByAgent' => 'Open incidenten per agent',
	'UI-IncidentManagementOverview-OpenIncidentByCustomer' => 'Open incidenten per klant',
	'UI-IncidentManagementOverview-OpenIncidentByStatus' => 'Open incidenten per status',
]);

==> iTop-3.2.2-1-17851.zip: web/datamodels/2.x/itop-incident-mgmt-itil/dictionaries/nl.dict.itop-incident-mgmt-itil.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author Thomas Casteleyn <info@super-visions.com>
 * @author Jeffrey Bostoen <info@jeffreybostoen.be> (2018 - 2022)
 *
 */
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Menu:IncidentManagement' => 'Incident Management',
	'Menu:IncidentManagement+' => 'Incident Management',
	'Menu:Incident:Overview' => 'Overzicht',
	'Menu:Incident:Overview+' => 'Overzicht',
	'Menu:NewIncident' => 'Nieuw incident',
	'Menu:NewIncident+' => 'Maak een nieuw incident aan',
	'Menu:SearchIncidents' => 'Zoek naar incidenten',
	'Menu:SearchIncidents+' => 'Zoek naar incidenten',
	'Menu:Incident:Shortcuts' => 'Snelkoppelingen',
	'Menu:Incident:Shortcuts+' => '',
	'Menu:Incident:MyIncidents' => 'Incidenten toegewezen aan mij',
	'Menu:Incident:MyIncidents+' => 'Incidenten toegewezen aan mij (als Agent)',
	'Menu:Incident:EscalatedIncidents' => 'Geëscaleerde incidenten',
	'Menu:Incident:EscalatedIncidents+' => 'Geëscaleerde incidenten',
	'Menu:Incident:OpenIncidents' => 'Alle open incidenten',
	'Menu:Incident:OpenIncidents+' => 'Alle open incidenten',
	'UI-IncidentManagementOverview-IncidentByPriority-last-14-days' => 'Incidenten van de afgelopen 14 dagen (per prioriteit)',
	'UI-IncidentManagementOverview-Last-14-days' => 'Incidenten van de afgelopen 14 dagen (per dag)',
	'UI-IncidentManagementOverview-OpenIncidentByStatus' => 'Open incidenten per status',
	'UI-IncidentManagementOverview-OpenIncidentByAgent' => 'Open incidenten per agent',
	'UI-IncidentManagementOverview-OpenIncidentByCustomer' => 'Open incidenten per klant',
));


// Dictionnay conventions
// Class:<class_name>
// Class:<class_name>+
// Class:<class_name>/Attribute:<attribute_code>
// Class:<class_name>/Attribute:<attribute_code>+
// Class:<class_name>/Attribute:<attribute_code>/Value:<value>
// Class:<class_name>/Attribute:<attribute_code>/Value:<value>+
// Class:<class_name>/Stimulus:<stimulus_code>
// Class:<class_name>/Stimulus:<stimulus_code>+

//
// Class: Incident
//

Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Class:Incident' => 'Incident',
	'Class:Incident+' => '',
	'Class:Incident/Attribute:status' => 'Status',
	'Class:Incident/Attribute:status+' => '',
	'Class:Incident/Attribute:status/Value:new' => 'Nieuw',
	'Class:Incident/Attribute:status/Value:new+' => '',
	'Class:Incident/Attribute:status/Value:escalated_tto' => 'Geëscaleerde TTO',
	'Class:Incident/Attribute:status/Value:escalated_tto+' => '',
	'Class:Incident/Attribute:status/Value:assigned' => 'Toegewezen',
	'Class:Incident/Attribute:status/Value:assigned+' => '',
	'Class:Incident/Attribute:status/Value:escalated_ttr' => 'Geëscaleerde TTR',
	'Class:Incident/Attribute:status/Value:escalated_ttr+' => '',
	'Class:Incident/Attribute:status/Value:waiting_for_approval' => 'Wachten op goedkeuring',
	'Class:Incident/Attribute:status/Value:waiting_for_approval+' => '',
	'Class:Incident/Attribute:status/Value:pending' => 'In afwachting',
	'Class:Incident/Attribute:status/Value:pending+' => '',
	'Class:Incident/Attribute:status/Value:resolved' => 'Opgelost',
	'Class:Incident/Attribute:status/Value:resolved+' => '',
	'Class:Incident/Attribute:status/Value:closed' => 'Gesloten',
	'Class:Incident/Attribute:status/Value:closed+' => '',
	'Class:Incident/Attribute:impact' => 'Impact',
	'Class:Incident/Attribute:impact+' => '',
	'Class:Incident/Attribute:impact/Value:1' => 'Afdeling',
	'Class:Incident/Attribute:impact/Value:1+' => '',
	'Class:Incident/Attribute:impact/Value:2' => 'Dienst',
	'Class:Incident/Attribute:impact/Value:2+' => '',
	'Class:Incident/Attribute:impact/Value:3' => 'Persoon',
	'Class:Incident/Attribute:impact/Value:3+' => '',
	'Class:Incident/Attribute:priority' => 'Prioriteit',
	'Class:Incident/Attribute:priority+' => '',
	'Class:Incident/Attribute:priority/Value:1' => 'Kritisch',
	'Class:Incident/Attribute:priority/Value:1+' => 'Kritisch',
	'Class:Incident/Attribute:priority/Value:2' => 'Hoog',
	'Class:Incident/Attribute:priority/Value:2+' => 'Hoog',
	'Class:Incident/Attribute:priority/Value:3' => 'Normaal',
	'Class:Incident/Attribute:priority/Value:3+' => 'Normaal',
	'Class:Incident/Attribute:priority/Value:4' => 'Laag',
	'Class:Incident/Attribute:priority/Value:4+' => 'Laag',
	'Class:Incident/Attribute:urgency' => 'Urgentie',
	'Class:Incident/Attribute:urgency+' => '',
	'Class:Incident/Attribute:urgency/Value:1' => 'Kritisch',
	'Class:Incident/Attribute:urgency/Value:1+' => 'Kritisch',
	'Class:Incident/Attribute:urgency/Value:2' => 'Hoog',
	'Class:Incident/Attribute:urgency/Value:2+' => 'Hoog',
	'Class:Incident/Attribute:urgency/Value:3' => 'Normaal',
	'Class:Incident/Attribute:urgency/Value:3+' => 'Normaal',
	'Class:Incident/Attribute:urgency/Value:4' => 'Laag',
	'Class:Incident/Attribute:urgency/Value:4+' => 'Laag',
	'Class:Incident/Attribute:origin' => 'Oorsprong',
	'Class:Incident/Attribute:origin+' => '',
	'Class:Incident/Attribute:origin/Value:in_person' => 'Persoonlijk',
	'Class:Incident/Attribute:origin/Value:in_person+' => 'Mondeling, in persoon',
	'Class:Incident/Attribute:origin/Value:chat' => 'Chat',
	'Class:Incident/Attribute:origin/Value:chat+' => 'Chat',
	'Class:Incident/Attribute:origin/Value:mail' => 'E-mail',
	'Class:Incident/Attribute:origin/Value:mail+' => 'E-mail',
	'Class:Incident/Attribute:origin/Value:monitoring' => 'Monitoring',
	'Class:Incident/Attribute:origin/Value:monitoring+' => 'Monitoring',
	'Class:Incident/Attribute:origin/Value:phone' => 'Telefoon',
	'Class:Incident/Attribute:origin/Value:phone+' => 'Telefoon',
	'Class:Incident/Attribute:origin/Value:portal' => 'Portaal',
	'Class:Incident/Attribute:origin/Value:portal+' => 'Portaal',
	'Class:Incident/Attribute:service_id' => 'Service',
	'Class:Incident/Attribute:service_id+' => '',
	'Class:Incident/Attribute:service_name' => 'Naam service',
	'Class:Incident/Attribute:service_name+' => '',
	'Class:Incident/Attribute:servicesubcategory_id' => 'Subcategorie service',
	'Class:Incident/Attribute:servicesubcategory_id+' => '',
	'Class:Incident/Attribute:servicesubcategory_name' => 'Naam subcategorie service',
	'Class:Incident/Attribute:servicesubcategory_name+' => '',
	'Class:Incident/Attribute:escalation_flag' => 'Geëscaleerd',
	'Class:Incident/Attribute:escalation_flag+' => '',
	'Class:Incident/Attribute:escalation_flag/Value:no' => 'Nee',
	'Class:Incident/Attribute:escalation_flag/Value:no+' => 'Nee',
	'Class:Incident/Attribute:escalation_flag/Value:yes' => 'Ja',
	'Class:Incident/Attribute:escalation_flag/Value:yes+' => 'Ja',
	'Class:Incident/Attribute:escalation_reason' => 'Reden voor escalatie',
	'Class:Incident/Attribute:escalation_reason+' => '',
	'Class:Incident/Attribute:assignment_date' => 'Toegewezen sinds',
	'Class:Incident/Attribute:assignment_date+' => '',
	'Class:Incident/Attribute:resolution_date' => 'Opgelost sinds',
	'Class:Incident/Attribute:resolution_date+' => '',
	'Class:Incident/Attribute:last_pending_date' => 'Laatst in afwachting sinds',
	'Class:Incident/Attribute:last_pending_date+' => 'Laatste datum waarop het incident de status in afwachting had',
	'Class:Incident/Attribute:cumulatedpending' => 'Totaal in afwachting',
	'Class:Incident/Attribute:cumulatedpending+' => '',
	'Class:Incident/Attribute:tto' => 'TTO',
	'Class:Incident/Attribute:tto+' => '',
	'Class:Incident/Attribute:ttr' => 'TTR',
	'Class:Incident/Attribute:ttr+' => '',
	'Class:Incident/Attribute:tto_escalation_deadline' => 'Deadline TTO',
	'Class:Incident/Attribute:tto_escalation_deadline+' => '',
	'Class:Incident/Attribute:sla_tto_passed' => 'SLA TTO gepasseerd',
	'Class:Incident/Attribute:sla_tto_passed+' => '',
	'Class:Incident/Attribute:sla_tto_over' => 'SLA TTO overschreden',
	'Class:Incident/Attribute:sla_tto_over+' => '',
	'Class:Incident/Attribute:ttr_escalation_deadline' => 'Deadline TTR',
	'Class:Incident/Attribute:ttr_escalation_deadline+' => '',
	'Class:Incident/Attribute:sla_ttr_passed' => 'SLA TTR gepasseerd',
	'Class:Incident/Attribute:sla_ttr_passed+' => '',
	'Class:Incident/Attribute:sla_ttr_over' => 'SLA TTR overschreden',
	'Class:Incident/Attribute:sla_ttr_over+' => '',
	'Class:Incident/Attribute:time_spent' => 'Gespendeerde tijd',
	'Class:Incident/Attribute:time_spent+' => '',
	'Class:Incident/Attribute:resolution_code' => 'Code oplossing',
	'Class:Incident/Attribute:resolution_code+' => '',
	'Class:Incident/Attribute:resolution_code/Value:assistance' => 'Assistentie',
	'Class:Incident/Attribute:resolution_code/Value:assistance+' => 'Assistentie',
	'Class:Incident/Attribute:resolution_code/Value:bug fixed' => 'Bug opgelost',
	'Class:Incident/Attribute:resolution_code/Value:bug fixed+' => 'Bug opgelost',
	'Class:Incident/Attribute:resolution_code/Value:hardware repair' => 'Hardware gerepareerd',
	'Class:Incident/Attribute:resolution_code/Value:hardware repair+' => 'Hardware gerepareerd',
	'Class:Incident/Attribute:resolution_code/Value:other' => 'Anders',
	'Class:Incident/Attribute:resolution_code/Value:other+' => 'Anders',
	'Class:Incident/Attribute:resolution_code/Value:software patch' => 'Softwarepatch',
	'Class:Incident/Attribute:resolution_code/Value:software patch+' => 'Softwarepatch',
	'Class:Incident/Attribute:resolution_code/Value:system update' => 'Systeemupdate',
	'Class:Incident/Attribute:resolution_code/Value:system update+' => 'Systeemupdate',
	'Class:Incident/Attribute:resolution_code/Value:training' => 'Training',
	'Class:Incident/Attribute:resolution_code/Value:training+' => 'Training',
	'Class:Incident/Attribute:solution' => 'Oplossing',
	'Class:Incident/Attribute:solution+' => 'Oplossing',
	'Class:Incident/Attribute:pending_reason' => 'Reden in afwachting',
	'Class:Incident/Attribute:pending_reason+' => 'Reden waarvoor het in afwachting staat',
	'Class:Incident/Attribute:parent_incident_id' => 'Hoofdincident',
	'Class:Incident/Attribute:parent_incident_id+' => '',
	'Class:Incident/Attribute:parent_incident_ref' => 'Ref. hoofdincident',
	'Class:Incident/Attribute:parent_incident_ref+' => '',
	'Class:Incident/Attribute:parent_change_id' => 'Hoofdchange',
	'Class:Incident/Attribute:parent_change_id+' => '',
	'Class:Incident/Attribute:parent_change_ref' => 'Ref. hoofdchange',
	'Class:Incident/Attribute:parent_change_ref+' => '',
	'Class:Incident/Attribute:parent_problem_id' => 'Hoofdprobleem',
	'Class:Incident/Attribute:parent_problem_id+' => '',
	'Class:Incident/Attribute:parent_problem_ref' => 'Ref. hoofdprobleem',
	'Class:Incident/Attribute:parent_problem_ref+' => '',
	'Class:Incident/Attribute:related_request_list' => 'Subverzoeken',
	'Class:Incident/Attribute:related_request_list+' => '',
	'Class:Incident/Attribute:child_incidents_list' => 'Subincidenten',
	'Class:Incident/Attribute:child_incidents_list+' => 'Alle subincidenten gerelateerd aan dit incident',
	'Class:Incident/Attribute:public_log' => 'Publieke log',
	'Class:Incident/Attribute:public_log+' => '',
	'Class:Incident/Attribute:user_satisfaction' => 'Klanttevredenheid',
	'Class:Incident/Attribute:user_satisfaction+' => '',
	'Class:Incident/Attribute:user_satisfaction/Value:1' => 'Erg tevreden',
	'Class:Incident/Attribute:user_satisfaction/Value:1+' => 'Erg tevreden',
	'Class:Incident/Attribute:user_satisfaction/Value:2' => 'Tevreden',
	'Class:Incident/Attribute:user_satisfaction/Value:2+' => 'Tevreden',
	'Class:Incident/Attribute:user_satisfaction/Value:3' => 'Ontevreden',
	'Class:Incident/Attribute:user_satisfaction/Value:3+' => 'Ontevreden',
	'Class:Incident/Attribute:user_satisfaction/Value:4' => 'Erg ontevreden',
	'Class:Incident/Attribute:user_satisfaction/Value:4+' => 'Erg ontevreden',
	'Class:Incident/Attribute:user_comment' => 'Reactie gebruiker',
	'Class:Incident/Attribute:user_comment+' => '',
	'Class:Incident/Attribute:parent_incident_id_friendlyname' => 'Ref. hoofdincident',
	'Class:Incident/Attribute:parent_incident_id_friendlyname+' => '',
	'Class:Incident/Stimulus:ev_assign' => 'Wijs toe',
	'Class:Incident/Stimulus:ev_assign+' => '',
	'Class:Incident/Stimulus:ev_reassign' => 'Wijs opnieuw toe',
	'Class:Incident/Stimulus:ev_reassign+' => '',
	'Class:Incident/Stimulus:ev_pending' => 'In afwachting',
	'Class:Incident/Stimulus:ev_pending+' => '',
	'Class:Incident/Stimulus:ev_timeout' => 'Time-out',
	'Class:Incident/Stimulus:ev_timeout+' => '',
	'Class:Incident/Stimulus:ev_autoresolve' => 'Los automatisch op',
	'Class:Incident/Stimulus:ev_autoresolve+' => '',
	'Class:Incident/Stimulus:ev_autoclose' => 'Sluit automatisch',
	'Class:Incident/Stimulus:ev_autoclose+' => '',
	'Class:Incident/Stimulus:ev_resolve' => 'Los op',
	'Class:Incident/Stimulus:ev_resolve+' => '',
	'Class:Incident/Stimulus:ev_close' => 'Sluit dit incident',
	'Class:Incident/Stimulus:ev_close+' => '',
	'Class:Incident/Stimulus:ev_reopen' => 'Heropen',
	'Class:Incident/Stimulus:ev_reopen+' => '',
	'Class:Incident/Error:CannotAssignParentIncidentIdToSelf' => 'Kan het incident niet aan zichzelf toewijzen als hoofdincident',
	'Class:Incident/Method:ResolveChildTickets' => 'ResolveChildTickets',
	'Class:Incident/Method:ResolveChildTickets+' => 'Pas de oplossing ook toe op subverzoeken (ev_autoresolve) en neem deze kenmerken over: service, team, agent, oplossing',
	'Tickets:Related:OpenIncidents' => 'Open incidenten',
));
